IntExtensions extension

on

Properties

borderRadius → BorderRadius

Available on int?, provided by the IntExtensions extension

no setter
days → Duration

Available on int?, provided by the IntExtensions extension

no setter
getBoolInt → bool

Available on int?, provided by the IntExtensions extension

Returns true if given value is 1, else returns false
no setter
height → Widget

Available on int?, provided by the IntExtensions extension

Leaves given height of space
no setter
hours → Duration

Available on int?, provided by the IntExtensions extension

no setter
microseconds → Duration

Available on int?, provided by the IntExtensions extension

no setter
milliseconds → Duration

Available on int?, provided by the IntExtensions extension

no setter
minutes → Duration

Available on int?, provided by the IntExtensions extension

no setter
seconds → Duration

Available on int?, provided by the IntExtensions extension

no setter
size → Size

Available on int?, provided by the IntExtensions extension

Returns Size
no setter
toMonthDaySuffix → String

Available on int?, provided by the IntExtensions extension

no setter
width → Widget

Available on int?, provided by the IntExtensions extension

Leaves given width of space
no setter

Methods

isBetween(num first, num second) → bool

Available on int?, provided by the IntExtensions extension

Returns if a number is between first and second
isSuccessful() → bool

Available on int?, provided by the IntExtensions extension

HTTP status code
toMonthName({bool isHalfName = false}) → String

Available on int?, provided by the IntExtensions extension

toWeekDay({bool isHalfName = false}) → String

Available on int?, provided by the IntExtensions extension

validate({int value = 0}) → int

Available on int?, provided by the IntExtensions extension

Validate given int is not null and returns given value if null.